==> qt6-translations_6.9.2.orig.tar.xz: qttranslations-everywhere-src-6.9.2/translations/qtwebsockets_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv_SE">
<context>
    <name>QQmlWebSocket</name>
    <message>
        <source>Messages can only be sent when the socket is open.</source>
        <translation>Meddelanden kan endast skickas när uttaget är öppet.</translation>
    </message>
    <message>
        <source>QQmlWebSocket is not ready.</source>
        <translation>QQmlWebSocket är inte redo.</translation>
    </message>
</context>
<context>
    <name>QQmlWebSocketServer</name>
    <message>
        <source>QQmlWebSocketServer is not ready.</source>
        <translation>QQmlWebSocketServer är inte redo.</translation>
    </message>
</context>
<context>
    <name>QWebSocket</name>
    <message>
        <source>Connection closed</source>
        <translation>Anslutningen är stängd</translation>
    </message>
    <message>
        <source>Invalid URL.</source>
        <translation>Ogiltig URL.</translation>
    </message>
    <message>
        <source>Invalid resource name.</source>
        <translation>Ogiltigt resursnamn.</translation>
    </message>
    <message>
        <source>SSL Sockets are not supported on this platform.</source>
        <translation>SSL-uttag stöds inte på denna plattform.</translation>
    </message>
    <message>
        <source>Out of memory.</source>
        <translation>Slut på minne.</translation>
    </message>
    <message>
        <source>Unsupported WebSocket scheme: %1</source>
        <translation>WebSocket-schemat stöds inte: %1</translation>
    </message>
    <message>
        <source>Error writing bytes to socket: %1.</source>
        <translation>Fel vid skrivning av bytes till uttag: %1.</translation>
    </message>
    <message>
        <source>Bytes written %1 != %2.</source>
        <translation>Bytes skrivna %1 != %2.</translation>
    </message>
    <message>
        <source>Invalid statusline in response: %1.</source>
        <translation>Ogiltig statusline i svar: %1.</translation>
    </message>
    <message>
        <source>Malformed header in response: %1.</source>
        <translation>Felformaterad rubrik i svar: %1.</translation>
    </message>
    <message>
        <source>QWebSocketPrivate::processHandshake: Connection closed while reading header.</source>
        <translation>QWebSocketPrivate::processHandshake: Anslutningen stängdes vid läsning av rubrik.</translation>
    </message>
    <message>
        <source>QWebSocketPrivate::processHandshake: Invalid statusline in response: %1.</source>
        <translation>QWebSocketPrivate::processHandshake: Ogiltig statusline i svar: %1.</translation>
    </message>
    <message>
        <source>The protocols attribute contains newlines. Possible attack detected.</source>
        <translation>Protokollets attribut innehåller nyrader. Potentiell attack upptäcktes.</translation>
    </message>
    <message>
        <source>Accept-Key received from server %1 does not match the client key %2.</source>
        <translation>Accept-Key som togs emot från servern %1 matchar inte klientnyckeln %2.</translation>
    </message>
    <message>
        <source>Handshake: Server requests a version that we don&apos;t support: %1.</source>
        <translation>Handskakning: Servern begär en version som vi inte har stöd för: %1.</translation>
    </message>
    <message>
        <source>QWebSocketPrivate::processHandshake: Unknown error condition encountered. Aborting connection.</source>
        <translation>QWebSocketPrivate::processHandshake: Okänt felvillkor påträffades. Avbryter anslutningen.</translation>
    </message>
    <message>
        <source>QWebSocketPrivate::processHandshake: Unhandled http status code: %1 (%2).</source>
        <translation>QWebSocketPrivate::processHandshake: Ohanterad http-statuskod: %1 (%2).</translation>
    </message>
    <message>
        <source>The resource name contains newlines. Possible attack detected.</source>
        <translation>Resursnamnet innehåller nyrader. Potentiell attack upptäcktes.</translation>
    </message>
    <message>
        <source>The hostname contains newlines. Possible attack detected.</source>
        <translation>Värdnamnet innehåller nyrader. Potentiell attack upptäcktes.</translation>
    </message>
    <message>
        <source>The origin contains newlines. Possible attack detected.</source>
        <translation>Ursprunget innehåller nyrader. Potentiell attack upptäcktes.</translation>
    </message>
    <message>
        <source>The extensions attribute contains newlines. Possible attack detected.</source>
        <translation>Attributet tillägg innehåller nyrader. Potentiell attack upptäcktes.</translation>
    </message>
</context>
<context>
    <name>QWebSocketDataProcessor</name>
    <message>
        <source>Received Continuation frame, while there is nothing to continue.</source>
        <translation>Tog emot Continuation-ram, men det finns ingenting att fortsätta.</translation>
    </message>
    <message>
        <source>All data frames after the initial data frame must have opcode 0 (continuation).</source>
        <translation>Alla dataramar efter den initiala dataramen måste ha opcode 0 (continuation).</translation>
    </message>
    <message>
        <source>Received message is too big.</source>
        <translation>Tog emot meddelande som är för stort.</translation>
    </message>
    <message>
        <source>Invalid UTF-8 code encountered.</source>
        <translation>Ogiltig UTF-8-kod togs emot.</translation>
    </message>
    <message>
        <source>Payload of close frame is too small.</source>
        <translation>Nyttolast för stängningsram är för liten.</translation>
    </message>
    <message>
        <source>Invalid close code %1 detected.</source>
        <translation>Ogiltig stängningskod %1 upptäcktes.</translation>
    </message>
    <message>
        <source>Invalid opcode detected: %1</source>
        <translation>Ogiltig opcode upptäcktes: %1</translation>
    </message>
    <message>
        <source>Timeout when reading data from socket.</source>
        <translation>Tidsgräns överstegs vid läsning av data från uttag.</translation>
    </message>
</context>
<context>
    <name>QWebSocketFrame</name>
    <message>
        <source>Waiting for more data from socket.</source>
        <translation>Väntar på mer data från uttaget.</translation>
    </message>
    <message>
        <source>Error occurred while reading header from the network: %1</source>
        <translation>Fel inträffade vid läsning av rubrik från nätverket: %1</translation>
    </message>
    <message>
        <source>Error occurred while reading from the network: %1</source>
        <translation>Fel inträffade vid läsning från nätverket: %1</translation>
    </message>
    <message>
        <source>Lengths smaller than 126 must be expressed as one byte.</source>
        <translation>Längder mindre än 126 måste uttryckas som en byte.</translation>
    </message>
    <message>
        <source>Something went wrong during reading from the network.</source>
        <translation>Någonting gick fel vid läsning från nätverket.</translation>
    </message>
    <message>
        <source>Highest bit of payload length is not 0.</source>
        <translation>Högsta biten för nyttolastlängden är inte 0.</translation>
    </message>
    <message>
        <source>Lengths smaller than 65536 (2^16) must be expressed as 2 bytes.</source>
        <translation>Längder mindre än  65536 (2^16) måste uttryckas som 2 bytes.</translation>
    </message>
    <message>
        <source>Error while reading from the network: %1.</source>
        <translation>Fel vid läsning från nätverket: %1.</translation>
    </message>
    <message>
        <source>Maximum framesize exceeded.</source>
        <translation>Maximal ramstorlek överstegs.</translation>
    </message>
    <message>
        <source>Some serious error occurred while reading from the network.</source>
        <translation>Några allvarliga fel inträffade vid läsning från nätverket.</translation>
    </message>
    <message>
        <source>Rsv field is non-zero</source>
        <translation>Rsv-fältet är icke-noll</translation>
    </message>
    <message>
        <source>Used reserved opcode</source>
        <translation>Använt reserverad opcode</translation>
    </message>
    <message>
        <source>Control frame is larger than 125 bytes</source>
        <translation>Kontrollram är större än 125 bytes</translation>
    </message>
    <message>
        <source>Control frames cannot be fragmented</source>
        <translation>Kontrollramar kan inte fragmenteras</translation>
    </message>
</context>
<context>
    <name>QWebSocketHandshakeResponse</name>
    <message>
        <source>Access forbidden.</source>
        <translation>Åtkomst förbjuden.</translation>
    </message>
    <message>
        <source>Unsupported version requested.</source>
        <translation>Begärd version stöds inte.</translation>
    </message>
    <message>
        <source>One of the headers contains a newline. Possible attack detected.</source>
        <translation>En av rubrikerna innehöll en nyrad. Potentiell attack upptäcktes.</translation>
    </message>
    <message>
        <source>Bad handshake request received.</source>
        <translation>Felaktig handskakningsbegäran togs emot.</translation>
    </message>
</context>
<context>
    <name>QWebSocketServer</name>
    <message>
        <source>Server closed.</source>
        <translation>Servern är stängd.</translation>
    </message>
    <message>
        <source>Header is too large.</source>
        <translation>Rubriken är för stor.</translation>
    </message>
    <message>
        <source>Too many pending connections.</source>
        <translation>För många väntande anslutningar.</translation>
    </message>
    <message>
        <source>Read handshake request header failed.</source>
        <translation>Begäransrubrik för läshandskakning misslyckades.</translation>
    </message>
    <message>
        <source>Upgrade to WebSocket failed.</source>
        <translation>Uppgradering till WebSocket misslyckades.</translation>
    </message>
    <message>
        <source>Invalid response received.</source>
        <translation>Ogiltigt svar togs emot.</translation>
    </message>
</context>
</TS>

==> qt6-translations_6.10.2.orig.tar.xz: qttranslations-everywhere-src-6.10.2/translations/qtwebsockets_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>QQmlWebSocket</name>
    <message>
        <source>Messages can only be sent when the socket is open.</source>
        <translation>Meddelanden kan endast skickas när uttaget är öppet.</translation>
    </message>
    <message>
        <source>QQmlWebSocket is not ready.</source>
        <translation>QQmlWebSocket är inte redo.</translation>
    </message>
</context>
<context>
    <name>QQmlWebSocketServer</name>
    <message>
        <source>QQmlWebSocketServer is not ready.</source>
        <translation>QQmlWebSocketServer är inte redo.</translation>
    </message>
</context>
<context>
    <name>QWebSocket</name>
    <message>
        <source>Connection closed</source>
        <translation>Anslutningen är stängd</translation>
    </message>
    <message>
        <source>Invalid URL.</source>
        <translation>Ogiltig URL.</translation>
    </message>
    <message>
        <source>Invalid resource name.</source>
        <translation>Ogiltigt resursnamn.</translation>
    </message>
    <message>
        <source>SSL Sockets are not supported on this platform.</source>
        <translation>SSL-uttag stöds inte på denna plattform.</translation>
    </message>
    <message>
        <source>Out of memory.</source>
        <translation>Slut på minne.</translation>
    </message>
    <message>
        <source>Unsupported WebSocket scheme: %1</source>
        <translation>WebSocket-schemat stöds inte: %1</translation>
    </message>
    <message>
        <source>Error writing bytes to socket: %1.</source>
        <translation>Fel vid skrivning av bytes till uttag: %1.</translation>
    </message>
    <message>
        <source>Bytes written %1 != %2.</source>
        <translation>Bytes skrivna %1 != %2.</translation>
    </message>
    <message>
        <source>QWebSocketPrivate::processHandshake: Unsupported WWW-Authenticate challenge encountered.</source>
        <extracomment>&apos;WWW-Authenticate&apos; is the HTTP header.</extracomment>
        <translation>QWebSocketPrivate::processHandshake: WWW-Authenticate-challenge stöds inte.</translation>
    </message>
    <message>
        <source>QWebSocketPrivate::processHandshake: Unsupported WWW-Authenticate challenges encountered.</source>
        <translation>QWebSocketPrivate::processHandshake: WWW-Authenticate-challenges stöds inte.</translation>
    </message>
    <message>
        <source>Header is too large</source>
        <translation>Rubriken är för stor</translation>
    </message>
    <message>
        <source>Read handshake request header failed</source>
        <translation>Rubrik för läshandskakningsbegäran misslyckades</translation>
    </message>
    <message>
        <source>Read handshake request status failed</source>
        <translation>Status för läshandskakningsbegäran misslyckades</translation>
    </message>
    <message>
        <source>Parsing handshake request header failed</source>
        <translation>Tolkning av begäransrubrik för handskakning misslyckades</translation>
    </message>
    <message>
        <source>WebSocket server has chosen protocol %1 which has not been requested</source>
        <translation>WebSocket-servern har valt protokollet %1 som inte har begärts</translation>
    </message>
    <message>
        <source>Accept-Key received from server %1 does not match the client key %2.</source>
        <translation>Accept-Key som togs emot från servern %1 matchar inte klientnyckeln %2.</translation>
    </message>
    <message>
        <source>Invalid parameter encountered during protocol upgrade: %1</source>
        <translation>Ogiltig parameter påträffades under protokolluppgradering :%1</translation>
    </message>
    <message>
        <source>Handshake: Server requests a version that we don&apos;t support: %1.</source>
        <translation>Handskakning: Servern begär en version som vi inte har stöd för: %1.</translation>
    </message>
    <message>
        <source>QWebSocketPrivate::processHandshake: Unknown error condition encountered. Aborting connection.</source>
        <translation>QWebSocketPrivate::processHandshake: Okänt felvillkor påträffades. Avbryter anslutningen.</translation>
    </message>
    <message>
        <source>QWebSocket::processHandshake: Host requires authentication</source>
        <translation>QWebSocket::processHandshake: Värden kräver autentisering</translation>
    </message>
    <message>
        <source>QWebSocketPrivate::processHandshake: Unhandled http status code: %1 (%2).</source>
        <translation>QWebSocketPrivate::processHandshake: Ohanterad http-statuskod: %1 (%2).</translation>
    </message>
    <message>
        <source>The resource name contains newlines. Possible attack detected.</source>
        <translation>Resursnamnet innehåller nyrader. Potentiell attack upptäcktes.</translation>
    </message>
    <message>
        <source>The hostname contains newlines. Possible attack detected.</source>
        <translation>Värdnamnet innehåller nyrader. Potentiell attack upptäcktes.</translation>
    </message>
    <message>
        <source>The origin contains newlines. Possible attack detected.</source>
        <translation>Ursprunget innehåller nyrader. Potentiell attack upptäcktes.</translation>
    </message>
    <message>
        <source>The extensions attribute contains newlines. Possible attack detected.</source>
        <translation>Attributet tillägg innehåller nyrader. Potentiell attack upptäcktes.</translation>
    </message>
    <message>
        <source>Connection refused</source>
        <translation>Anslutningen nekades</translation>
    </message>
</context>
<context>
    <name>QWebSocketDataProcessor</name>
    <message>
        <source>Received Continuation frame, while there is nothing to continue.</source>
        <translation>Tog emot Continuation-ram, men det finns ingenting att fortsätta.</translation>
    </message>
    <message>
        <source>All data frames after the initial data frame must have opcode 0 (continuation).</source>
        <translation>Alla dataramar efter den initiala dataramen måste ha opcode 0 (continuation).</translation>
    </message>
    <message>
        <source>Received message is too big.</source>
        <translation>Tog emot meddelande som är för stort.</translation>
    </message>
    <message>
        <source>Invalid UTF-8 code encountered.</source>
        <translation>Ogiltig UTF-8-kod togs emot.</translation>
    </message>
    <message>
        <source>Payload of close frame is too small.</source>
        <translation>Nyttolast för stängningsram är för liten.</translation>
    </message>
    <message>
        <source>Invalid close code %1 detected.</source>
        <translation>Ogiltig stängningskod %1 upptäcktes.</translation>
    </message>
    <message>
        <source>Invalid opcode detected: %1</source>
        <translation>Ogiltig opcode upptäcktes: %1</translation>
    </message>
    <message>
        <source>Timeout when reading data from socket.</source>
        <translation>Tidsgräns överstegs vid läsning av data från uttag.</translation>
    </message>
</context>
<context>
    <name>QWebSocketFrame</name>
    <message>
        <source>Waiting for more data from socket.</source>
        <translation>Väntar på mer data från uttaget.</translation>
    </message>
    <message>
        <source>Error occurred while reading header from the network: %1</source>
        <translation>Fel inträffade vid läsning av rubrik från nätverket: %1</translation>
    </message>
    <message>
        <source>Error occurred while reading from the network: %1</source>
        <translation>Fel inträffade vid läsning från nätverket: %1</translation>
    </message>
    <message>
        <source>Lengths smaller than 126 must be expressed as one byte.</source>
        <translation>Längder mindre än 126 måste uttryckas som en byte.</translation>
    </message>
    <message>
        <source>Something went wrong during reading from the network.</source>
        <translation>Någonting gick fel vid läsning från nätverket.</translation>
    </message>
    <message>
        <source>Highest bit of payload length is not 0.</source>
        <translation>Högsta biten för nyttolastlängden är inte 0.</translation>
    </message>
    <message>
        <source>Lengths smaller than 65536 (2^16) must be expressed as 2 bytes.</source>
        <translation>Längder mindre än  65536 (2^16) måste uttryckas som 2 bytes.</translation>
    </message>
    <message>
        <source>Error while reading from the network: %1.</source>
        <translation>Fel vid läsning från nätverket: %1.</translation>
    </message>
    <message>
        <source>Maximum framesize exceeded.</source>
        <translation>Maximal ramstorlek överstegs.</translation>
    </message>
    <message>
        <source>Some serious error occurred while reading from the network.</source>
        <translation>Några allvarliga fel inträffade vid läsning från nätverket.</translation>
    </message>
    <message>
        <source>Rsv field is non-zero</source>
        <translation>Rsv-fältet är icke-noll</translation>
    </message>
    <message>
        <source>Used reserved opcode</source>
        <translation>Använt reserverad opcode</translation>
    </message>
    <message>
        <source>Control frame is larger than 125 bytes</source>
        <translation>Kontrollram är större än 125 bytes</translation>
    </message>
    <message>
        <source>Control frames cannot be fragmented</source>
        <translation>Kontrollramar kan inte fragmenteras</translation>
    </message>
</context>
<context>
    <name>QWebSocketHandshakeResponse</name>
    <message>
        <source>Access forbidden.</source>
        <translation>Åtkomst förbjuden.</translation>
    </message>
    <message>
        <source>Unsupported version requested.</source>
        <translation>Begärd version stöds inte.</translation>
    </message>
    <message>
        <source>One of the headers contains a newline. Possible attack detected.</source>
        <translation>En av rubrikerna innehöll en nyrad. Potentiell attack upptäcktes.</translation>
    </message>
    <message>
        <source>Bad handshake request received.</source>
        <translation>Felaktig handskakningsbegäran togs emot.</translation>
    </message>
</context>
<context>
    <name>QWebSocketServer</name>
    <message>
        <source>Server closed.</source>
        <translation>Servern är stängd.</translation>
    </message>
    <message>
        <source>Header is too large.</source>
        <translation>Rubriken är för stor.</translation>
    </message>
    <message>
        <source>Too many pending connections.</source>
        <translation>För många väntande anslutningar.</translation>
    </message>
    <message>
        <source>Read handshake request header failed.</source>
        <translation>Begäransrubrik för läshandskakning misslyckades.</translation>
    </message>
    <message>
        <source>Upgrade to WebSocket failed.</source>
        <translation>Uppgradering till WebSocket misslyckades.</translation>
    </message>
    <message>
        <source>Invalid response received.</source>
        <translation>Ogiltigt svar togs emot.</translation>
    </message>
</context>
</TS>
